# Reference

<!-- DO NOT EDIT: This document was generated by Puppet Strings -->

## Table of Contents

### Classes

* [`cloudfile`](#cloudfile): Download archived packages from various locations and optionally local install.

### Defined types

* [`cloudfile::getfile`](#cloudfilegetfile): Download archived packages from various locations and optionally local install.

## Classes

### <a name="cloudfile"></a>`cloudfile`

A module to download application files from cloud filestores or http/https hosted packages,
currently compatable with AWS and Azure cloud providers. Package installation features will
 be added in future releases, including running a template to install custom applications
that cannot use the `package` resource type.

#### Examples

##### retrieve an application call invader from s3 storage to linux

```puppet
class { 'cloudfile':
  application    => 'invader',
  package_name   => 'invader.tar.gz',
  package_uri    => 's3://chrislorro',
  extract        => true,
  cloud_download => aws_s3,
  aws_region     => eu-west-2,
}
```

##### retrieve an application call invader from s3 storage and install the application

```puppet
class { 'cloudfile':
  application     => 'mcafee',
  package_name    => 'McAfee.zip',
  package_uri     => 'https://chrislorro.blob.core.windows.net/puppet,
  extract         => true,
  cloud_download  => 'secure',
  install_package => true,
  token           => 'sp=rwd&st=2022-01-27T11:46[…]sig=2ytxxRcpND1Khs4UgUL1tfMxOwHsZMMit'
  installer_exe    => McAfee.exe,
  install_options => [ '/SILENT', '/INSTALL=AGENT']
}
```

#### Parameters

The following parameters are available in the `cloudfile` class:

* [`application`](#application)
* [`install_package`](#install_package)
* [`package_name`](#package_name)
* [`package_uri`](#package_uri)
* [`extract`](#extract)
* [`cloud_download`](#cloud_download)
* [`installer_exe`](#installer_exe)
* [`install_options`](#install_options)
* [`token`](#token)
* [`aws_region`](#aws_region)
* [`installer`](#installer)

##### <a name="application"></a>`application`

Data type: `String`

The application name that is being installed, use the exact application
string for windows so that the package resource runs idempotent

Default value: ``undef``

##### <a name="install_package"></a>`install_package`

Data type: `Boolean`

Boolean true or false to install the extracted package

Default value: ``false``

##### <a name="package_name"></a>`package_name`

Data type: `String`

The package name that will be downloaded from cloud storage

Default value: ``undef``

##### <a name="package_uri"></a>`package_uri`

Data type: `String`

The URL of the cloud storage where the package is stored

Default value: ``undef``

##### <a name="extract"></a>`extract`

Data type: `Boolean`

set this parameter to extract the package from an archive file,
it defaults to true because we expect a compressed file

Default value: ``true``

##### <a name="cloud_download"></a>`cloud_download`

Data type: `Enum[ 'standard',
        'aws_s3',
        'secure' ]`

The cloud platform that is used to host the application package
Accepts 3 different parametes:
*- standard: standard download using http://URI https://URI
*- aws_s3: Dowload using s3://URI and optional $install_options
*- secure: Download using a secure token, must be used exclusive with token parameter

Default value: ``undef``

##### <a name="installer_exe"></a>`installer_exe`

Data type: `Optional[String]`

Optional parameter to install the package (this option will be enhanced in the next release)

Default value: ``undef``

##### <a name="install_options"></a>`install_options`

Data type: `Optional[Array]`

Optional parameter to pass installation options to the package installer

Default value: ``undef``

##### <a name="token"></a>`token`

Data type: `Optional[String]`

Optional parameter for passing a token to the package URL tested on AZ for now,
 token is expected if IAM is configured on the platform

Default value: ``undef``

##### <a name="aws_region"></a>`aws_region`

Data type: `Optional[String]`

Optional parameter for the AWS region, if this is not set for,
windows agents the package uses a default deployed with the sdk

Default value: ``undef``

##### <a name="installer"></a>`installer`

Optional paramter for executing install scripts on Linux only

## Defined types

### <a name="cloudfilegetfile"></a>`cloudfile::getfile`

A module to download application files from cloud filestores or http/https hosted packages,
currently compatable with AWS and Azure cloud providers. Package installation features will
 be added in future releases, including running a template to install custom applications
that cannot use the `package` resource type.

#### Examples

##### usage AWS windows installation:

```puppet
cloudfile::getfile { 'putty-64bit-0.76-installer.msi.zip':
  application     => 'PuTTY release 0.76 (64-bit)',
  cloud_download  => 'aws_s3',
  extract         => true,
  package_uri     => 's3://chrislorro',
  aws_region      => 'eu-west2',
  install_package => true,
  $installer_exe   => 'putty-64bit-0.76-installer.msi',
}
```

##### retrieve an application call McAfee from AZ storage and install the application

```puppet
cloudfile::getfile { 'McAfee.zip':
  application     => 'mcafee',
  package_uri     => 'https://chrislorro.blob.core.windows.net/puppet,
  extract         => true,
  cloud_download  => 'secure',
  install_package => true,
  token           => 'sp=rwd&st=2022-01-27T11:46[…]sig=2ytxxRcpND1Khs4UgUL1tfMxOwHsZMMit'
  installer_exe    => McAfee.exe,
  install_options => [ '/SILENT', '/INSTALL=AGENT']
}
```

#### Parameters

The following parameters are available in the `cloudfile::getfile` defined type:

* [`application`](#application)
* [`package_name`](#package_name)
* [`package_uri`](#package_uri)
* [`extract`](#extract)
* [`cloud_download`](#cloud_download)
* [`install_package`](#install_package)
* [`installer_exe`](#installer_exe)
* [`install_options`](#install_options)
* [`token`](#token)
* [`aws_region`](#aws_region)
* [`installer`](#installer)

##### <a name="application"></a>`application`

Data type: `String`

The application name that is being installed, use the exact application
string for windows so that the package resource runs idempotent

Default value: ``undef``

##### <a name="package_name"></a>`package_name`

The package name that will be downloaded from cloud storage

##### <a name="package_uri"></a>`package_uri`

Data type: `String`

The URL of the cloud storage where the package is stored

Default value: ``undef``

##### <a name="extract"></a>`extract`

Data type: `Boolean`

set this parameter to extract the package from an archive file,
it defaults to true because we expect a compressed file

Default value: ``true``

##### <a name="cloud_download"></a>`cloud_download`

Data type: `Enum[ 'standard',
        'aws_s3',
        'secure' ]`

The cloud platform that is used to host the application package
Accepts 3 different parametes:
*- standard: standard download using http://URI https://URI
*- aws_s3: Dowload using s3://URI and optional $install_options
*- secure: Download using a secure token, must be used exclusive with token parameter

Default value: ``undef``

##### <a name="install_package"></a>`install_package`

Data type: `Boolean`

Boolean true or false to install the extracted package

Default value: ``false``

##### <a name="installer_exe"></a>`installer_exe`

Data type: `Optional[String]`

Optional parameter to install the package (this option will be enhanced in the next release)

Default value: ``undef``

##### <a name="install_options"></a>`install_options`

Data type: `Optional[Array]`

Optional parameter to pass installation options to the package installer

Default value: ``undef``

##### <a name="token"></a>`token`

Data type: `Optional[String]`

Optional parameter for passing a token to the package URL tested on AZ for now,
 token is expected if IAM is configured on the platform

Default value: ``undef``

##### <a name="aws_region"></a>`aws_region`

Data type: `Optional[String]`

Optional parameter for the AWS region, if this is not set for,
windows agents the package uses a default deployed with the sdk

Default value: ``undef``

##### <a name="installer"></a>`installer`

Optional paramter for executing install scripts on Linux only